@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 # copyright 2003-2010 Sylvain Thenault, all rights reserved.
 # contact mailto:thenault@gmail.com
@@ -20,59 +20,22 @@
 """this module contains a set of functions to handle inference on astng trees
 """
 
-from __future__ import generators
-
 __doctype__ = "restructuredtext en"
 
 from itertools import chain
 import sys
 
-try:
-    GeneratorExit # introduced in py2.5
-except NameError:
-    class GeneratorExit(Exception): pass
+from logilab.astng import nodes
 
-from logilab.astng import nodes, raw_building
 from logilab.astng.manager import ASTNGManager
-from logilab.astng import ASTNGError, InferenceError, UnresolvableName, \
-     NoDefault, NotFoundError, ASTNGBuildingException
-from logilab.astng.bases import YES, Instance, InferenceContext, \
+from logilab.astng.exceptions import (ASTNGBuildingException, ASTNGError,
+    InferenceError, NoDefault, NotFoundError, UnresolvableName)
+from logilab.astng.bases import YES, Instance, InferenceContext, Generator, \
      _infer_stmts, copy_context, path_wrapper, raise_if_nothing_infered
 from logilab.astng.protocols import _arguments_infer_argname
 
 MANAGER = ASTNGManager()
 
-_CONST_PROXY = {
-    type(None): raw_building.build_class('NoneType'),
-    bool: MANAGER.astng_from_class(bool),
-    int: MANAGER.astng_from_class(int),
-    long: MANAGER.astng_from_class(long),
-    float: MANAGER.astng_from_class(float),
-    complex: MANAGER.astng_from_class(complex),
-    str: MANAGER.astng_from_class(str),
-    unicode: MANAGER.astng_from_class(unicode),
-    }
-_CONST_PROXY[type(None)].parent = _CONST_PROXY[bool].parent
-if sys.version_info >= (2, 6):
-    _CONST_PROXY[bytes] = MANAGER.astng_from_class(bytes)
-
-# TODO : find a nicer way to handle this situation; we should at least
-# be able to avoid calling MANAGER.astng_from_class(const.value.__class__)
-# each time (if we can not avoid the property). However __proxied introduced an
-# infinite recursion (see https://bugs.launchpad.net/pylint/+bug/456870)
-def _set_proxied(const):
-    return _CONST_PROXY[const.value.__class__]
-nodes.Const._proxied = property(_set_proxied)
-
-def Const_pytype(self):
-    return self._proxied.qname()
-nodes.Const.pytype = Const_pytype
-
-
-nodes.List._proxied = MANAGER.astng_from_class(list)
-nodes.Tuple._proxied = MANAGER.astng_from_class(tuple)
-nodes.Dict._proxied = MANAGER.astng_from_class(dict)
-
 
 class CallContext:
     """when inferring a function call, this class is used to remember values
@@ -236,7 +199,7 @@ def infer_from(self, context=None, asname=True):
     try:
         context = copy_context(context)
         context.lookupname = name
-        return _infer_stmts(module.getattr(name), context)
+        return _infer_stmts(module.getattr(name, ignore_locals=module is self.root()), context)
     except NotFoundError:
         raise InferenceError(name)
 nodes.From.infer = path_wrapper(infer_from)
